summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJon Hanna <jon@hackcraft.net>2015-08-14 18:28:00 +0100
committerJon Hanna <jon@hackcraft.net>2015-08-14 18:28:00 +0100
commitb07498db7d68ca9b899c243a108b5d086f6a3b32 (patch)
tree1dcded387e310c13b476ea3d7cacec12c1323a02
parent7dfc09b70f883472680a5b94521bcd04b6f019c8 (diff)
downloadcoreclr-b07498db7d68ca9b899c243a108b5d086f6a3b32.tar.gz
coreclr-b07498db7d68ca9b899c243a108b5d086f6a3b32.tar.bz2
coreclr-b07498db7d68ca9b899c243a108b5d086f6a3b32.zip
Fix typo "retrive" and "retrieved" to "retrieve" and "retrieved"
Mostly just in comments, test case and trace text, but the exception thrown if you try to GetInterfaceMap on an array type has it in the description.
-rw-r--r--src/classlibnative/nls/nlsinfo.cpp2
-rw-r--r--src/inc/tls.h2
-rw-r--r--src/jit/sm.h2
-rw-r--r--src/mscorlib/src/System/Reflection/Emit/AssemblyBuilder.cs2
-rw-r--r--src/mscorlib/src/System/Reflection/MethodInfo.cs2
-rw-r--r--src/mscorlib/src/mscorlib.txt2
-rw-r--r--src/pal/src/cruntime/wchar.cpp8
-rw-r--r--src/pal/tests/palsuite/filemapping_memmgt/GetModuleFileNameA/test1/GetModuleFileNameA.c4
-rw-r--r--src/pal/tests/palsuite/filemapping_memmgt/GetModuleFileNameA/test1/testinfo.dat2
-rw-r--r--src/pal/tests/palsuite/filemapping_memmgt/GetModuleFileNameA/test2/GetModuleFileNameA.c4
-rw-r--r--src/pal/tests/palsuite/filemapping_memmgt/GetModuleFileNameA/test2/testinfo.dat2
-rw-r--r--src/pal/tests/palsuite/filemapping_memmgt/GetModuleFileNameW/test1/GetModuleFileNameW.c4
-rw-r--r--src/pal/tests/palsuite/filemapping_memmgt/GetModuleFileNameW/test1/testinfo.dat2
-rw-r--r--src/pal/tests/palsuite/filemapping_memmgt/GetModuleFileNameW/test2/GetModuleFileNameW.c4
-rw-r--r--src/pal/tests/palsuite/filemapping_memmgt/GetModuleFileNameW/test2/testinfo.dat2
-rw-r--r--src/pal/tests/palsuite/filemapping_memmgt/GetProcessHeap/test1/GetProcessHeap.c4
-rw-r--r--src/pal/tests/palsuite/filemapping_memmgt/GetProcessHeap/test1/testinfo.dat4
-rw-r--r--src/pal/tests/palsuite/filemapping_memmgt/HeapAlloc/test1/HeapAlloc.c2
-rw-r--r--src/pal/tests/palsuite/filemapping_memmgt/HeapAlloc/test2/HeapAlloc.c2
-rw-r--r--src/pal/tests/palsuite/filemapping_memmgt/HeapAlloc/test3/HeapAlloc.c2
-rw-r--r--src/pal/tests/palsuite/filemapping_memmgt/HeapFree/test1/HeapFree.c2
-rw-r--r--src/pal/tests/palsuite/filemapping_memmgt/ReadProcessMemory/ReadProcessMemory_neg1/ReadProcessMemory_neg.c6
-rw-r--r--src/pal/tests/palsuite/filemapping_memmgt/ReadProcessMemory/test1/ReadProcessMemory.c6
-rw-r--r--src/pal/tests/palsuite/filemapping_memmgt/ReadProcessMemory/test2/test2.c2
-rw-r--r--src/pal/tests/palsuite/miscellaneous/GetCalendarInfoW/test1/GetCalendarInfoW.c6
-rw-r--r--src/pal/tests/palsuite/miscellaneous/GetCalendarInfoW/test2/GetCalendarInfoW.c6
-rw-r--r--src/pal/tests/palsuite/miscellaneous/GetDateFormatW/GetDateFormatW_neg1/GetDateFormatW_neg.c2
-rw-r--r--src/pal/tests/palsuite/miscellaneous/GetDateFormatW/GetDateFormatW_neg2/GetDateFormatW_neg.c2
-rw-r--r--src/pal/tests/palsuite/miscellaneous/GetDateFormatW/test1/GetDateFormatW.c2
-rw-r--r--src/pal/tests/palsuite/pal_specific/PAL_GetPALDirectoryW/test1/PAL_GetPALDirectoryW.c2
-rw-r--r--src/pal/tests/palsuite/pal_specific/PAL_GetUserTempDirectoryW/test1/PAL_GetUserTempDirectoryW.c6
-rw-r--r--src/pal/tests/palsuite/pal_specific/PAL_GetUserTempDirectoryW/test1/testinfo.dat2
-rw-r--r--src/vm/comdelegate.cpp2
-rw-r--r--src/vm/excep.cpp2
-rw-r--r--src/vm/frames.h2
-rw-r--r--src/vm/i386/asmhelpers.asm4
-rw-r--r--src/vm/memberload.cpp4
-rw-r--r--src/vm/proftoeeinterfaceimpl.cpp2
-rw-r--r--src/vm/stdinterfaces.cpp2
-rw-r--r--src/vm/tlbexport.cpp2
-rw-r--r--src/zap/zapinfo.cpp2
41 files changed, 62 insertions, 62 deletions
diff --git a/src/classlibnative/nls/nlsinfo.cpp b/src/classlibnative/nls/nlsinfo.cpp
index d2a4f02a7f..70f04e13c9 100644
--- a/src/classlibnative/nls/nlsinfo.cpp
+++ b/src/classlibnative/nls/nlsinfo.cpp
@@ -684,7 +684,7 @@ FCIMPLEND
////////////////////////////////////////////////////////////////////////
//
-// Call the Win32 GetLocaleInfo() using the specified lcid to retrive
+// Call the Win32 GetLocaleInfo() using the specified lcid to retrieve
// the native digits, probably from the registry override. The return
// indicates whether the call was successful.
//
diff --git a/src/inc/tls.h b/src/inc/tls.h
index 4c51a3a6f2..94f5574905 100644
--- a/src/inc/tls.h
+++ b/src/inc/tls.h
@@ -31,7 +31,7 @@
#endif // FEATURE_IMPLICIT_TLS
-// Pointer to a function that retrives the TLS data for a specific index.
+// Pointer to a function that retrieves the TLS data for a specific index.
typedef LPVOID (*POPTIMIZEDTLSGETTER)();
//---------------------------------------------------------------------------
diff --git a/src/jit/sm.h b/src/jit/sm.h
index 1fa92305a1..baa6fb9521 100644
--- a/src/jit/sm.h
+++ b/src/jit/sm.h
@@ -59,7 +59,7 @@ public :
NativeSize += StateWeights[stateID];
}
- // Given an SM opcode retrive the weight for this single opcode state.
+ // Given an SM opcode retrieve the weight for this single opcode state.
// For example, ID for single opcode state SM_NOSHOW is 2.
inline short GetWeightForOpcode(SM_OPCODE opcode)
{
diff --git a/src/mscorlib/src/System/Reflection/Emit/AssemblyBuilder.cs b/src/mscorlib/src/System/Reflection/Emit/AssemblyBuilder.cs
index 15196f58f3..3ee05717d3 100644
--- a/src/mscorlib/src/System/Reflection/Emit/AssemblyBuilder.cs
+++ b/src/mscorlib/src/System/Reflection/Emit/AssemblyBuilder.cs
@@ -1766,7 +1766,7 @@ namespace System.Reflection.Emit
// In memory this module is not the manifest module and has a valid file token
// On disk it will be the manifest module so lets clean the file token
- // We should not retrive FileToken after the assembly has been saved
+ // We should not retrieve FileToken after the assembly has been saved
// If that is absolutely necessary, we need two separate fields on ModuleBuilderData:
// the in memory file token and the on disk file token.
assemblyModule.m_moduleData.FileToken = 0;
diff --git a/src/mscorlib/src/System/Reflection/MethodInfo.cs b/src/mscorlib/src/System/Reflection/MethodInfo.cs
index 2dd7defab5..87dd0f611b 100644
--- a/src/mscorlib/src/System/Reflection/MethodInfo.cs
+++ b/src/mscorlib/src/System/Reflection/MethodInfo.cs
@@ -433,7 +433,7 @@ namespace System.Reflection
// We cannot do simple object identity comparisons for generic methods.
// Equals will be called in CerHashTable when RuntimeType+RuntimeTypeCache.GetGenericMethodInfo()
- // retrive items from and insert items into s_methodInstantiations which is a CerHashtable.
+ // retrieve items from and insert items into s_methodInstantiations which is a CerHashtable.
RuntimeMethodInfo mi = obj as RuntimeMethodInfo;
diff --git a/src/mscorlib/src/mscorlib.txt b/src/mscorlib/src/mscorlib.txt
index d3e4cea674..1a036b88c3 100644
--- a/src/mscorlib/src/mscorlib.txt
+++ b/src/mscorlib/src/mscorlib.txt
@@ -579,7 +579,7 @@ Argument_ImpersonateUser = Unable to impersonate user.
Argument_InvalidHexFormat = Improperly formatted hex string.
Argument_InvalidSite = Invalid site.
Argument_InterfaceMap = 'this' type cannot be an interface itself.
-Argument_ArrayGetInterfaceMap = Interface maps for generic interfaces on arrays cannot be retrived.
+Argument_ArrayGetInterfaceMap = Interface maps for generic interfaces on arrays cannot be retrieved.
Argument_InvalidName = Invalid name.
Argument_InvalidDirectoryOnUrl = Invalid directory on URL.
Argument_InvalidUrl = Invalid URL.
diff --git a/src/pal/src/cruntime/wchar.cpp b/src/pal/src/cruntime/wchar.cpp
index 83c086c0ec..0eb211cc7f 100644
--- a/src/pal/src/cruntime/wchar.cpp
+++ b/src/pal/src/cruntime/wchar.cpp
@@ -797,7 +797,7 @@ PAL_towlower( wchar_16 c )
if (!GetUnicodeData(c, &dataRec))
{
- TRACE( "Unable to retrive unicode data for the character %c.\n", c );
+ TRACE( "Unable to retrieve unicode data for the character %c.\n", c );
LOGEXIT("towlower returns int %d\n", c );
PERF_EXIT(towlower);
return c;
@@ -856,7 +856,7 @@ PAL_towupper( wchar_16 c )
if (!GetUnicodeData(c, &dataRec))
{
- TRACE( "Unable to retrive unicode data for the character %c.\n", c );
+ TRACE( "Unable to retrieve unicode data for the character %c.\n", c );
LOGEXIT("towupper returns int %d\n", c );
PERF_EXIT(towupper);
return c;
@@ -908,7 +908,7 @@ PAL_iswupper( wchar_16 c )
if (!GetUnicodeData(c, &dataRec))
{
- TRACE( "Unable to retrive unicode data for the character %c.\n", c );
+ TRACE( "Unable to retrieve unicode data for the character %c.\n", c );
goto exit;
}
@@ -954,7 +954,7 @@ PAL_iswlower( wchar_16 c )
if (!GetUnicodeData(c, &dataRec))
{
- TRACE( "Unable to retrive unicode data for the character %c.\n", c );
+ TRACE( "Unable to retrieve unicode data for the character %c.\n", c );
goto exit;
}
diff --git a/src/pal/tests/palsuite/filemapping_memmgt/GetModuleFileNameA/test1/GetModuleFileNameA.c b/src/pal/tests/palsuite/filemapping_memmgt/GetModuleFileNameA/test1/GetModuleFileNameA.c
index 5ae45bd5ab..a2bde0eb90 100644
--- a/src/pal/tests/palsuite/filemapping_memmgt/GetModuleFileNameA/test1/GetModuleFileNameA.c
+++ b/src/pal/tests/palsuite/filemapping_memmgt/GetModuleFileNameA/test1/GetModuleFileNameA.c
@@ -8,7 +8,7 @@
** Source: getmodulefilenamea.c
**
** Purpose: Positive test the GetModuleFileName API.
-** Call GetModuleFileName to retrive the specified
+** Call GetModuleFileName to retrieve the specified
** module full path and file name
**
**
@@ -53,7 +53,7 @@ int __cdecl main(int argc, char *argv[])
}
- //retrive the specified module full path and file name
+ //retrieve the specified module full path and file name
ModuleNameLength = GetModuleFileName(
ModuleHandle,//specified module handle
ModuleFileNameBuf,//buffer for module file name
diff --git a/src/pal/tests/palsuite/filemapping_memmgt/GetModuleFileNameA/test1/testinfo.dat b/src/pal/tests/palsuite/filemapping_memmgt/GetModuleFileNameA/test1/testinfo.dat
index 6f2b81d3d0..eca731fba7 100644
--- a/src/pal/tests/palsuite/filemapping_memmgt/GetModuleFileNameA/test1/testinfo.dat
+++ b/src/pal/tests/palsuite/filemapping_memmgt/GetModuleFileNameA/test1/testinfo.dat
@@ -9,5 +9,5 @@ Name = Positive test for GetModuleFileNameA API
TYPE = DEFAULT
EXE1 = getmodulefilenamea
Description
-=Test the GetModuleFileNameA to retrive the specified module
+=Test the GetModuleFileNameA to retrieve the specified module
=full path and file name
diff --git a/src/pal/tests/palsuite/filemapping_memmgt/GetModuleFileNameA/test2/GetModuleFileNameA.c b/src/pal/tests/palsuite/filemapping_memmgt/GetModuleFileNameA/test2/GetModuleFileNameA.c
index 0904fc7bb9..46d66b4f4c 100644
--- a/src/pal/tests/palsuite/filemapping_memmgt/GetModuleFileNameA/test2/GetModuleFileNameA.c
+++ b/src/pal/tests/palsuite/filemapping_memmgt/GetModuleFileNameA/test2/GetModuleFileNameA.c
@@ -8,7 +8,7 @@
** Source: getmodulefilenamea.c
**
** Purpose: Positive test the GetModuleFileNameA API.
-** Call GetModuleFileName to retrive current process
+** Call GetModuleFileName to retrieve current process
** full path and file name by passing a NULL module handle
**
**
@@ -33,7 +33,7 @@ int __cdecl main(int argc, char *argv[])
}
- //retrive the current process full path and file name
+ //retrieve the current process full path and file name
//by passing a NULL module handle
ModuleNameLength = GetModuleFileName(
NULL, //a NULL handle
diff --git a/src/pal/tests/palsuite/filemapping_memmgt/GetModuleFileNameA/test2/testinfo.dat b/src/pal/tests/palsuite/filemapping_memmgt/GetModuleFileNameA/test2/testinfo.dat
index 6fe97cf241..8f0b730875 100644
--- a/src/pal/tests/palsuite/filemapping_memmgt/GetModuleFileNameA/test2/testinfo.dat
+++ b/src/pal/tests/palsuite/filemapping_memmgt/GetModuleFileNameA/test2/testinfo.dat
@@ -9,5 +9,5 @@ Name = Positive test for GetModuleFileNameA API
TYPE = DEFAULT
EXE1 = getmodulefilenamea
Description
-=Test the GetModuleFileNameA to retrive current process full
+=Test the GetModuleFileNameA to retrieve current process full
=full path and file name by passing a NULL module handle
diff --git a/src/pal/tests/palsuite/filemapping_memmgt/GetModuleFileNameW/test1/GetModuleFileNameW.c b/src/pal/tests/palsuite/filemapping_memmgt/GetModuleFileNameW/test1/GetModuleFileNameW.c
index 71b567c99b..8ecd52da8d 100644
--- a/src/pal/tests/palsuite/filemapping_memmgt/GetModuleFileNameW/test1/GetModuleFileNameW.c
+++ b/src/pal/tests/palsuite/filemapping_memmgt/GetModuleFileNameW/test1/GetModuleFileNameW.c
@@ -7,7 +7,7 @@
**
** Source: getmodulefilenamew.c
**
-** Purpose: Test the GetModuleFileNameW to retrive the specified module
+** Purpose: Test the GetModuleFileNameW to retrieve the specified module
** full path and file name in UNICODE.
**
**
@@ -63,7 +63,7 @@ int __cdecl main(int argc, char *argv[])
}
- //retrive the specified module full path and file name
+ //retrieve the specified module full path and file name
ModuleNameLength = GetModuleFileName(
ModuleHandle,//specified module handle
ModuleFileNameBuf,//buffer for module file name
diff --git a/src/pal/tests/palsuite/filemapping_memmgt/GetModuleFileNameW/test1/testinfo.dat b/src/pal/tests/palsuite/filemapping_memmgt/GetModuleFileNameW/test1/testinfo.dat
index 83edede75d..2790b215b3 100644
--- a/src/pal/tests/palsuite/filemapping_memmgt/GetModuleFileNameW/test1/testinfo.dat
+++ b/src/pal/tests/palsuite/filemapping_memmgt/GetModuleFileNameW/test1/testinfo.dat
@@ -9,5 +9,5 @@ Name = Positive test for GetModuleFileNameW API
TYPE = DEFAULT
EXE1 = getmodulefilenamew
Description
-=Test the GetModuleFileNameW to retrive the specified module
+=Test the GetModuleFileNameW to retrieve the specified module
=full path and file name in UNICODE
diff --git a/src/pal/tests/palsuite/filemapping_memmgt/GetModuleFileNameW/test2/GetModuleFileNameW.c b/src/pal/tests/palsuite/filemapping_memmgt/GetModuleFileNameW/test2/GetModuleFileNameW.c
index c81a24c4a7..3944a4d406 100644
--- a/src/pal/tests/palsuite/filemapping_memmgt/GetModuleFileNameW/test2/GetModuleFileNameW.c
+++ b/src/pal/tests/palsuite/filemapping_memmgt/GetModuleFileNameW/test2/GetModuleFileNameW.c
@@ -8,7 +8,7 @@
** Source: getmodulefilenamew.c
**
** Purpose: Positive test the GetModuleFileName API.
-** Call GetModuleFileName to retrive current process
+** Call GetModuleFileName to retrieve current process
** full path and file name by passing a NULL module handle
** in UNICODE
**
@@ -37,7 +37,7 @@ int __cdecl main(int argc, char *argv[])
ModuleFileNameBuf = malloc(MODULENAMEBUFFERSIZE*sizeof(WCHAR));
- //retrive the current process full path and file name
+ //retrieve the current process full path and file name
//by passing a NULL module handle
ModuleNameLength = GetModuleFileName(
NULL, //a NULL handle
diff --git a/src/pal/tests/palsuite/filemapping_memmgt/GetModuleFileNameW/test2/testinfo.dat b/src/pal/tests/palsuite/filemapping_memmgt/GetModuleFileNameW/test2/testinfo.dat
index 392a3dc232..93e35facde 100644
--- a/src/pal/tests/palsuite/filemapping_memmgt/GetModuleFileNameW/test2/testinfo.dat
+++ b/src/pal/tests/palsuite/filemapping_memmgt/GetModuleFileNameW/test2/testinfo.dat
@@ -9,5 +9,5 @@ Name = Positive test for GetModuleFileNameW API
TYPE = DEFAULT
EXE1 = getmodulefilenamew
Description
-=Test the GetModuleFileNameW to retrive current process full
+=Test the GetModuleFileNameW to retrieve current process full
=full path and file name by passing a NULL module handle in UNICODE
diff --git a/src/pal/tests/palsuite/filemapping_memmgt/GetProcessHeap/test1/GetProcessHeap.c b/src/pal/tests/palsuite/filemapping_memmgt/GetProcessHeap/test1/GetProcessHeap.c
index ee0a4558fb..4d54ad486d 100644
--- a/src/pal/tests/palsuite/filemapping_memmgt/GetProcessHeap/test1/GetProcessHeap.c
+++ b/src/pal/tests/palsuite/filemapping_memmgt/GetProcessHeap/test1/GetProcessHeap.c
@@ -8,7 +8,7 @@
** Source: getprocheap.c
**
** Purpose: Positive test the GetProcessHeap API.
-** Call GetProcessHeap to retrive the handle of
+** Call GetProcessHeap to retrieve the handle of
** calling process heap
**
**
@@ -27,7 +27,7 @@ int __cdecl main(int argc, char *argv[])
ExitProcess(FAIL);
}
- //Retrive the calling process heap handle
+ //Retrieve the calling process heap handle
ProcessHeapHandle = GetProcessHeap();
if(!ProcessHeapHandle)
diff --git a/src/pal/tests/palsuite/filemapping_memmgt/GetProcessHeap/test1/testinfo.dat b/src/pal/tests/palsuite/filemapping_memmgt/GetProcessHeap/test1/testinfo.dat
index d999c957b1..6b4f2fefba 100644
--- a/src/pal/tests/palsuite/filemapping_memmgt/GetProcessHeap/test1/testinfo.dat
+++ b/src/pal/tests/palsuite/filemapping_memmgt/GetProcessHeap/test1/testinfo.dat
@@ -5,8 +5,8 @@
Version = 1.0
Section = Filemapping_memmgt
Function = GetProcessHeap
-Name = Positive test for GetProcessHeap API retrive the handle of calling process heap
+Name = Positive test for GetProcessHeap API retrieve the handle of calling process heap
TYPE = DEFAULT
EXE1 = getprocessheap
Description
-=Test the GetProcessHeap to retrive the handle of the calling process heap
+=Test the GetProcessHeap to retrieve the handle of the calling process heap
diff --git a/src/pal/tests/palsuite/filemapping_memmgt/HeapAlloc/test1/HeapAlloc.c b/src/pal/tests/palsuite/filemapping_memmgt/HeapAlloc/test1/HeapAlloc.c
index 61f0e20105..7a59d75111 100644
--- a/src/pal/tests/palsuite/filemapping_memmgt/HeapAlloc/test1/HeapAlloc.c
+++ b/src/pal/tests/palsuite/filemapping_memmgt/HeapAlloc/test1/HeapAlloc.c
@@ -32,7 +32,7 @@ int __cdecl main(int argc, char *argv[])
ExitProcess(FAIL);
}
- /* Retrive the calling process heap handle */
+ /* Retrieve the calling process heap handle */
ProcessHeapHandle = GetProcessHeap();
if(!ProcessHeapHandle)
diff --git a/src/pal/tests/palsuite/filemapping_memmgt/HeapAlloc/test2/HeapAlloc.c b/src/pal/tests/palsuite/filemapping_memmgt/HeapAlloc/test2/HeapAlloc.c
index 0133359fde..9ae9ca61db 100644
--- a/src/pal/tests/palsuite/filemapping_memmgt/HeapAlloc/test2/HeapAlloc.c
+++ b/src/pal/tests/palsuite/filemapping_memmgt/HeapAlloc/test2/HeapAlloc.c
@@ -30,7 +30,7 @@ int __cdecl main(int argc, char *argv[])
ExitProcess(FAIL);
}
- //Retrive the calling process heap handle
+ //Retrieve the calling process heap handle
ProcessHeapHandle = GetProcessHeap();
if(!ProcessHeapHandle)
diff --git a/src/pal/tests/palsuite/filemapping_memmgt/HeapAlloc/test3/HeapAlloc.c b/src/pal/tests/palsuite/filemapping_memmgt/HeapAlloc/test3/HeapAlloc.c
index 6dcf4be78a..e69478d782 100644
--- a/src/pal/tests/palsuite/filemapping_memmgt/HeapAlloc/test3/HeapAlloc.c
+++ b/src/pal/tests/palsuite/filemapping_memmgt/HeapAlloc/test3/HeapAlloc.c
@@ -31,7 +31,7 @@ int __cdecl main(int argc, char *argv[])
ExitProcess(FAIL);
}
- //Retrive the calling process heap handle
+ //Retrieve the calling process heap handle
ProcessHeapHandle = GetProcessHeap();
if(!ProcessHeapHandle)
diff --git a/src/pal/tests/palsuite/filemapping_memmgt/HeapFree/test1/HeapFree.c b/src/pal/tests/palsuite/filemapping_memmgt/HeapFree/test1/HeapFree.c
index bd7c5544d0..7de76d9702 100644
--- a/src/pal/tests/palsuite/filemapping_memmgt/HeapFree/test1/HeapFree.c
+++ b/src/pal/tests/palsuite/filemapping_memmgt/HeapFree/test1/HeapFree.c
@@ -30,7 +30,7 @@ int __cdecl main(int argc, char *argv[])
return FAIL;
}
- /* Retrive the calling process heap handle */
+ /* Retrieve the calling process heap handle */
ProcessHeapHandle = GetProcessHeap();
if(!ProcessHeapHandle)
diff --git a/src/pal/tests/palsuite/filemapping_memmgt/ReadProcessMemory/test2/test2.c b/src/pal/tests/palsuite/filemapping_memmgt/ReadProcessMemory/test2/test2.c
index e066a246fe..5faabffead 100644
--- a/src/pal/tests/palsuite/filemapping_memmgt/ReadProcessMemory/test2/test2.c
+++ b/src/pal/tests/palsuite/filemapping_memmgt/ReadProcessMemory/test2/test2.c
@@ -187,7 +187,7 @@ int __cdecl main(int argc, char *argv[])
if(NULL == readProcessHandle)
{
- Fail("\nFailed to call OpenProcess API to retrive "
+ Fail("\nFailed to call OpenProcess API to retrieve "
"current process handle error code=%u\n",
GetLastError());
}
diff --git a/src/pal/tests/palsuite/miscellaneous/GetCalendarInfoW/test2/GetCalendarInfoW.c b/src/pal/tests/palsuite/miscellaneous/GetCalendarInfoW/test2/GetCalendarInfoW.c
index 0d3ad9183d..08cb2962ce 100644
--- a/src/pal/tests/palsuite/miscellaneous/GetCalendarInfoW/test2/GetCalendarInfoW.c
+++ b/src/pal/tests/palsuite/miscellaneous/GetCalendarInfoW/test2/GetCalendarInfoW.c
@@ -8,7 +8,7 @@
** Source: GetCalendarInfoW.c
**
** Purpose: Positive test the GetCalendarInfoW API.
-** Call GetCalendarInfoW to retrive the information of all
+** Call GetCalendarInfoW to retrieve the information of all
** calendars
**
**
@@ -53,11 +53,11 @@ int __cdecl main(int argc, char *argv[])
for(index=0; index<13; index++)
{
Calendar = index + 1;
- /*retrive the specified calendar info*/
+ /*retrieve the specified calendar info*/
err = GetCalendarInfoW(Locale,/*locale idendifier*/
Calendar, /*calendar identifier*/
CalType, /*calendar tyope*/
- NULL, /*buffer to store the retrive info*/
+ NULL, /*buffer to store the retreive info*/
0, /*alwayse zero*/
&dwValue);/*to store the requrest data*/
if(0 == err)
diff --git a/src/pal/tests/palsuite/miscellaneous/GetDateFormatW/GetDateFormatW_neg1/GetDateFormatW_neg.c b/src/pal/tests/palsuite/miscellaneous/GetDateFormatW/GetDateFormatW_neg1/GetDateFormatW_neg.c
index 520dad78e1..b9b426c24f 100644
--- a/src/pal/tests/palsuite/miscellaneous/GetDateFormatW/GetDateFormatW_neg1/GetDateFormatW_neg.c
+++ b/src/pal/tests/palsuite/miscellaneous/GetDateFormatW/GetDateFormatW_neg1/GetDateFormatW_neg.c
@@ -41,7 +41,7 @@ int __cdecl main(int argc, char *argv[])
DateSize = 0;
- /*retrive the buffer size*/
+ /*retrieve the buffer size*/
DateSize = GetDateFormatW(
DefaultLocale, /*system default locale*/
dwFlags, /*function option*/
diff --git a/src/pal/tests/palsuite/miscellaneous/GetDateFormatW/GetDateFormatW_neg2/GetDateFormatW_neg.c b/src/pal/tests/palsuite/miscellaneous/GetDateFormatW/GetDateFormatW_neg2/GetDateFormatW_neg.c
index beaf60a01e..7742d67340 100644
--- a/src/pal/tests/palsuite/miscellaneous/GetDateFormatW/GetDateFormatW_neg2/GetDateFormatW_neg.c
+++ b/src/pal/tests/palsuite/miscellaneous/GetDateFormatW/GetDateFormatW_neg2/GetDateFormatW_neg.c
@@ -53,7 +53,7 @@ int __cdecl main(int argc, char *argv[])
DateSize = 0;
- /*retrive the buffer size*/
+ /*retrieve the buffer size*/
DateSize = GetDateFormatW(
DefaultLocale, /*system default locale*/
dwFlags, /*function option*/
diff --git a/src/pal/tests/palsuite/miscellaneous/GetDateFormatW/test1/GetDateFormatW.c b/src/pal/tests/palsuite/miscellaneous/GetDateFormatW/test1/GetDateFormatW.c
index a2e8e924a8..92b2e70191 100644
--- a/src/pal/tests/palsuite/miscellaneous/GetDateFormatW/test1/GetDateFormatW.c
+++ b/src/pal/tests/palsuite/miscellaneous/GetDateFormatW/test1/GetDateFormatW.c
@@ -53,7 +53,7 @@ int __cdecl main(int argc, char *argv[])
DateSize = 0;
- /*retrive the buffer size*/
+ /*retrieve the buffer size*/
DateSize = GetDateFormatW(
DefaultLocale, /*system default locale*/
dwFlags, /*function option*/
diff --git a/src/pal/tests/palsuite/pal_specific/PAL_GetPALDirectoryW/test1/PAL_GetPALDirectoryW.c b/src/pal/tests/palsuite/pal_specific/PAL_GetPALDirectoryW/test1/PAL_GetPALDirectoryW.c
index d4e8426ac0..78bbd03d67 100644
--- a/src/pal/tests/palsuite/pal_specific/PAL_GetPALDirectoryW/test1/PAL_GetPALDirectoryW.c
+++ b/src/pal/tests/palsuite/pal_specific/PAL_GetPALDirectoryW/test1/PAL_GetPALDirectoryW.c
@@ -70,7 +70,7 @@ int __cdecl main(int argc, char *argv[])
if(FILE_ATTRIBUTE_DIRECTORY !=
(dwFileAttribute & FILE_ATTRIBUTE_DIRECTORY))
{
- Fail("The retrived directory name is not a valid directory!\n");
+ Fail("The retrieved directory name is not a valid directory!\n");
}
PAL_Terminate();
diff --git a/src/pal/tests/palsuite/pal_specific/PAL_GetUserTempDirectoryW/test1/PAL_GetUserTempDirectoryW.c b/src/pal/tests/palsuite/pal_specific/PAL_GetUserTempDirectoryW/test1/PAL_GetUserTempDirectoryW.c
index ff7b95cfd4..df4c6a213c 100644
--- a/src/pal/tests/palsuite/pal_specific/PAL_GetUserTempDirectoryW/test1/PAL_GetUserTempDirectoryW.c
+++ b/src/pal/tests/palsuite/pal_specific/PAL_GetUserTempDirectoryW/test1/PAL_GetUserTempDirectoryW.c
@@ -32,7 +32,7 @@ int __cdecl main(int argc, char *argv[])
ExitProcess(FAIL);
}
- //retrive the user temp directory
+ //retrieve the user temp directory
err = PAL_GetUserTempDirectory(ddtInstallationDependentDirectory, wDirectoryName, &cch);
if(0 == err || 0 == strlen(convertC(wDirectoryName)))
@@ -41,11 +41,11 @@ int __cdecl main(int argc, char *argv[])
}
- //retrive the attributes of a file or directory
+ //retrieve the attributes of a file or directory
dwFileAttribute = GetFileAttributesW(wDirectoryName);
- //check if the retrived attribute indicates a directory
+ //check if the retrieved attribute indicates a directory
if( FILE_ATTRIBUTE_DIRECTORY != (FILE_ATTRIBUTE_DIRECTORY & dwFileAttribute))
{
Fail("PAL_GetUserTempDirectoryW API returned a non-directory name!\n");
diff --git a/src/pal/tests/palsuite/pal_specific/PAL_GetUserTempDirectoryW/test1/testinfo.dat b/src/pal/tests/palsuite/pal_specific/PAL_GetUserTempDirectoryW/test1/testinfo.dat
index a8efb4be1c..8fe9f3eb14 100644
--- a/src/pal/tests/palsuite/pal_specific/PAL_GetUserTempDirectoryW/test1/testinfo.dat
+++ b/src/pal/tests/palsuite/pal_specific/PAL_GetUserTempDirectoryW/test1/testinfo.dat
@@ -9,5 +9,5 @@ Name = Positive test for PAL_GetUserTempDirectoryW API
TYPE = DEFAULT
EXE1 = pal_getusertempdirectoryw
Description
-=Test the PAL_GetUserTempDirectoryW to retrive the user temp
+=Test the PAL_GetUserTempDirectoryW to retrieve the user temp
=directory name
diff --git a/src/vm/comdelegate.cpp b/src/vm/comdelegate.cpp
index 193f6f4786..66a19ac817 100644
--- a/src/vm/comdelegate.cpp
+++ b/src/vm/comdelegate.cpp
@@ -3278,7 +3278,7 @@ MethodDesc* COMDelegate::GetDelegateCtor(TypeHandle delegateType, MethodDesc *pT
// 1, 4 - MulticastDelegate.ctor1 (simply assign _target and _methodPtr)
// 5 - MulticastDelegate.ctor2 (see table, takes 3 args)
// 2, 6 - MulticastDelegate.ctor3 (take shuffle thunk)
- // 3 - MulticastDelegate.ctor4 (take shuffle thunk, retrive MethodDesc) ???
+ // 3 - MulticastDelegate.ctor4 (take shuffle thunk, retrieve MethodDesc) ???
//
// 7 - Needs special handling
//
diff --git a/src/vm/excep.cpp b/src/vm/excep.cpp
index 3fe9f4f130..4c595409c7 100644
--- a/src/vm/excep.cpp
+++ b/src/vm/excep.cpp
@@ -11725,7 +11725,7 @@ BOOL CEHelper::CanMethodHandleException(CorruptionSeverity severity, PTR_MethodD
}
// If we have been asked to use the last active corruption severity (e.g. in cases of Reflection
- // or COM interop), then retrive it.
+ // or COM interop), then retrieve it.
if (severity == UseLast)
{
LOG((LF_EH, LL_INFO100, "CEHelper::CanMethodHandleException - Using LastActiveExceptionCorruptionSeverity.\n"));
diff --git a/src/vm/frames.h b/src/vm/frames.h
index 44e38bf155..ce65b38623 100644
--- a/src/vm/frames.h
+++ b/src/vm/frames.h
@@ -1891,7 +1891,7 @@ public:
virtual PCODE GetReturnAddress();
- // Retrives pointer to the lowest-addressed argument on
+ // Retrieves pointer to the lowest-addressed argument on
// the stack. Depending on the calling convention, this
// may or may not be the first argument.
TADDR GetPointerToArguments()
diff --git a/src/vm/i386/asmhelpers.asm b/src/vm/i386/asmhelpers.asm
index 4c7d6aab3b..93d10cd92c 100644
--- a/src/vm/i386/asmhelpers.asm
+++ b/src/vm/i386/asmhelpers.asm
@@ -470,7 +470,7 @@ _GetSpecificCpuTypeAsm@0 PROC public
push ecx
popfd ; Save the updated flags.
pushfd
- pop ecx ; Retrive the updated flags
+ pop ecx ; Retrieve the updated flags
xor ecx, eax ; Test if it actually changed (bit set means yes)
push eax
popfd ; Restore the flags
@@ -512,7 +512,7 @@ _GetSpecificCpuFeaturesAsm@4 PROC public
push ecx
popfd ; Save the updated flags.
pushfd
- pop ecx ; Retrive the updated flags
+ pop ecx ; Retrieve the updated flags
xor ecx, eax ; Test if it actually changed (bit set means yes)
push eax
popfd ; Restore the flags
diff --git a/src/vm/memberload.cpp b/src/vm/memberload.cpp
index 016acabd67..af38cc88ec 100644
--- a/src/vm/memberload.cpp
+++ b/src/vm/memberload.cpp
@@ -1090,7 +1090,7 @@ MemberLoader::FindMethod(
MODE_ANY;
} CONTRACT_END;
- // Retrive the right comparition function to use.
+ // Retrieve the right comparition function to use.
UTF8StringCompareFuncPtr StrCompFunc = FM_GetStrCompFunc(flags);
SString targetName(SString::Utf8Literal, pszName);
@@ -1487,7 +1487,7 @@ MemberLoader::FindField(MethodTable * pMT, LPCUTF8 pszName, PCCOR_SIGNATURE pSig
CONSISTENCY_CHECK(pMT->CheckLoadLevel(CLASS_LOAD_APPROXPARENTS));
- // Retrive the right comparition function to use.
+ // Retrieve the right comparition function to use.
UTF8StringCompareFuncPtr StrCompFunc = bCaseSensitive ? strcmp : stricmpUTF8;
// The following assert is very important, but we need to special case it enough
diff --git a/src/vm/proftoeeinterfaceimpl.cpp b/src/vm/proftoeeinterfaceimpl.cpp
index f23edcba0e..293d70c596 100644
--- a/src/vm/proftoeeinterfaceimpl.cpp
+++ b/src/vm/proftoeeinterfaceimpl.cpp
@@ -5656,7 +5656,7 @@ HRESULT ProfToEEInterfaceImpl::GetFunctionFromTokenAndTypeArgs(ModuleID moduleID
}
//*****************************************************************************
-// Retrive information about a given application domain, which is like a
+// Retrieve information about a given application domain, which is like a
// sub-process.
//*****************************************************************************
HRESULT ProfToEEInterfaceImpl::GetAppDomainInfo(AppDomainID appDomainId,
diff --git a/src/vm/stdinterfaces.cpp b/src/vm/stdinterfaces.cpp
index a716606053..5e2820184b 100644
--- a/src/vm/stdinterfaces.cpp
+++ b/src/vm/stdinterfaces.cpp
@@ -694,7 +694,7 @@ HRESULT GetITypeLibForAssembly(Assembly *pAssembly, ITypeLib **ppTLB, int bAutoC
goto ErrExit;
}
- // Retrive the major and minor version number.
+ // Retrieve the major and minor version number.
IfFailGo(GetTypeLibVersionForAssembly(pAssembly, &wMajor, &wMinor));
// Maybe the module was imported from COM, and we can get the libid of the existing typelib.
diff --git a/src/vm/tlbexport.cpp b/src/vm/tlbexport.cpp
index cb21fac29a..d7894b2210 100644
--- a/src/vm/tlbexport.cpp
+++ b/src/vm/tlbexport.cpp
@@ -5513,7 +5513,7 @@ void TypeLibExporter::GetWellKnownInterface(
CLSIDFromString(wzGuid, &guidTlb);
- // Retrive the major and minor version number.
+ // Retrieve the major and minor version number.
USHORT wMajor;
USHORT wMinor;
Assembly *pAssembly = pMT->GetAssembly();
diff --git a/src/zap/zapinfo.cpp b/src/zap/zapinfo.cpp
index d5bdbabb8c..0e874d0a7e 100644
--- a/src/zap/zapinfo.cpp
+++ b/src/zap/zapinfo.cpp
@@ -1598,7 +1598,7 @@ HRESULT ZapInfo::getBBProfileData (
_ASSERTE(foundEntry->md == md);
//
- // We found the md. Let's retrive the profile data.
+ // We found the md. Let's retrieve the profile data.
//
_ASSERTE(foundEntry->pos > 0); // The target position cannot be 0.
_ASSERTE(foundEntry->size >= sizeof(CORBBTPROF_METHOD_HEADER)); // The size must at least this
diff --git a/src/pal/tests/palsuite/filemapping_memmgt/ReadProcessMemory/ReadProcessMemory_neg1/ReadProcessMemory_neg.c b/src/pal/tests/palsuite/filemapping_memmgt/ReadProcessMemory/ReadProcessMemory_neg1/ReadProcessMemory_neg.c
index d8c11ea0a3..b79988837b 100644
--- a/src/pal/tests/palsuite/filemapping_memmgt/ReadProcessMemory/ReadProcessMemory_neg1/ReadProcessMemory_neg.c
+++ b/src/pal/tests/palsuite/filemapping_memmgt/ReadProcessMemory/ReadProcessMemory_neg1/ReadProcessMemory_neg.c
@@ -34,10 +34,10 @@ int __cdecl main(int argc, char *argv[])
return FAIL;
}
/*retrive the current process ID*/
ProcessID = GetCurrentProcessId();
/*retrive the current process handle*/
ProcessHandle = OpenProcess(
PROCESS_ALL_ACCESS,
FALSE, /*not inherited*/
@@ -45,7 +45,7 @@ int __cdecl main(int argc, char *argv[])
if(NULL == ProcessHandle)
{
- Fail("\nFailed to call OpenProcess API to retrive "
+ Fail("\nFailed to call OpenProcess API to retrieve "
"current process handle error code=%u\n",
GetLastError());
}
@@ -34,10 +34,10 @@ int __cdecl main(int argc, char *argv[])
return FAIL;
}
- /*retrive the current process ID*/
+ /*retrieve the current process ID*/
ProcessID = GetCurrentProcessId();
@@ -34,10 +34,10 @@ int __cdecl main(int argc, char *argv[])
ProcessID = GetCurrentProcessId();
- /*retrive the current process handle*/
+ /*retrieve the current process handle*/
ProcessHandle = OpenProcess(
PROCESS_ALL_ACCESS,
diff --git a/src/pal/tests/palsuite/filemapping_memmgt/ReadProcessMemory/test1/ReadProcessMemory.c b/src/pal/tests/palsuite/filemapping_memmgt/ReadProcessMemory/test1/ReadProcessMemory.c
index e9377ba033..1b630d71b0 100644
--- a/src/pal/tests/palsuite/filemapping_memmgt/ReadProcessMemory/test1/ReadProcessMemory.c
+++ b/src/pal/tests/palsuite/filemapping_memmgt/ReadProcessMemory/test1/ReadProcessMemory.c
@@ -35,10 +35,10 @@ int __cdecl main(int argc, char *argv[])
return FAIL;
}
/*retrive the current process ID*/
ProcessID = GetCurrentProcessId();
/*retrive the current process handle*/
ProcessHandle = OpenProcess(
PROCESS_VM_READ,/*access flag*/
FALSE, /*not inherited*/
@@ -46,7 +46,7 @@ int __cdecl main(int argc, char *argv[])
if(NULL == ProcessHandle)
{
- Fail("\nFailed to call OpenProcess API to retrive "
+ Fail("\nFailed to call OpenProcess API to retrieve "
"current process handle error code=%u\n",
GetLastError());
}
@@ -35,10 +35,10 @@ int __cdecl main(int argc, char *argv[])
return FAIL;
}
- /*retrive the current process ID*/
+ /*retrieve the current process ID*/
ProcessID = GetCurrentProcessId();
@@ -35,10 +35,10 @@ int __cdecl main(int argc, char *argv[])
ProcessID = GetCurrentProcessId();
- /*retrive the current process handle*/
+ /*retrieve the current process handle*/
ProcessHandle = OpenProcess(
PROCESS_VM_READ,/*access flag*/
diff --git a/src/pal/tests/palsuite/miscellaneous/GetCalendarInfoW/test1/GetCalendarInfoW.c b/src/pal/tests/palsuite/miscellaneous/GetCalendarInfoW/test1/GetCalendarInfoW.c
index 634103a752..6c72d211ca 100644
--- a/src/pal/tests/palsuite/miscellaneous/GetCalendarInfoW/test1/GetCalendarInfoW.c
+++ b/src/pal/tests/palsuite/miscellaneous/GetCalendarInfoW/test1/GetCalendarInfoW.c
@@ -8,7 +8,7 @@
** Source: GetCalendarInfoW.c
**
** Purpose: Positive test the GetCalendarInfoW API.
** Call GetCalendarInfoW to retrive the information of a
** calendar
**
**
@@ -33,7 +33,7 @@ int __cdecl main(int argc, char *argv[])
err = GetCalendarInfoW(Locale,/*locale idendifier*/
CAL_GREGORIAN, /*calendar identifier*/
CalType, /*calendar tyope*/
- NULL, /*buffer to store the retrive info*/
+ NULL, /*buffer to store the retrieve info*/
0, /*alwayse zero*/
&dwValue);/*to store the requrest data*/
if (0 == err)
@@ -44,7 +44,7 @@ int __cdecl main(int argc, char *argv[])
err = GetCalendarInfoW(Locale,/*locale idendifier*/
CAL_GREGORIAN_US, /*calendar identifier*/
CalType, /*calendar tyope*/
- NULL, /*buffer to store the retrive info*/
+ NULL, /*buffer to store the retreive info*/
0, /*alwayse zero*/
&dwValue);/*to store the requrest data*/
if (0 == err)
@@ -8,7 +8,7 @@
**
** Purpose: Positive test the GetCalendarInfoW API.
-** Call GetCalendarInfoW to retrive the information of a
+** Call GetCalendarInfoW to retrieve the information of a
** calendar
**